@@ -1,7 +1,6 @@
 from deployer.exceptions import ExecCommandFailed
 from deployer.node import Node, SimpleNode, SimpleNodeBase, dont_isolate_yet, required_property
 from deployer.utils import esc1
-import termcolor
 
 __all__ = ('Git', 'GitOverview' )
 
@@ -71,6 +70,13 @@ class Git(SimpleNode):
 
         self._checkout(commit)
 
+    def _before_checkout_hook(self, commit):
+        """ To be overridden. This function can throw an exception for
+        instance, in a case when it's not allowed to continue with the
+        checkout. (e.g. when git-grep matches a certain pattern that is not
+        allowed on the machine.) """
+        pass
+
     def _checkout(self, commit):
         """
         This will either clone or checkout the given commit. Changes in the
@@ -88,6 +94,8 @@ class Git(SimpleNode):
         with host.cd(self.repository_location):
             host.run('git fetch --all --prune')
 
+            self._before_checkout_hook(commit)
+
             # Stash
             if existed:
                 host.run('git stash')
@@ -113,28 +121,15 @@ class GitOverview(Node):
     Show a nice readable overview of all the git checkouts of all the services in the tree.
     """
     def show(self):
-        # Preparing results.
-        result = { }
-        def walk(service):
-            if service.isinstance(Git):
-                # In case that we have more hosts in this git checkout, call
-                # it for every individual isolation.
-                if service.is_isolated:
-                    result[service] = { i.service.host.slug: service.show_oneline() }
-                else:
-                    result[service] = { i.service.host.slug: i.service.show_oneline() for i in service.get_isolations() }
+        from deployer.inspection import filters, Inspector
 
-            for name, s in service.get_subservices():
-                if s.parent == service: # Make sure that we don't walk in loops (back to parent nodes.)
-                    walk(s)
-        walk(self.root)
+        def iterate():
+            iterator = Inspector(Inspector(self).get_root()).walk(filters.IsInstance(Git) & filters.PublicOnly)
+            for node in iterator:
+                full_path = '.'.join(Inspector(node).get_path())
+                checkout = str(node.show_oneline()).strip()
+                yield ' %-40s %s' % (full_path, checkout)
 
-        # Show results
-        print
-        for service, data in result.items():
-            print termcolor.colored(service.__repr__(path_only=True), service.get_group().color)
-
-            for host_slug, git_output in data.items():
-                print '      %-40s %s' % (termcolor.colored(host_slug, 'green'), git_output.strip())
+        self.console.lesspipe(iterate())
 
     __call__ = show
