@@ -3,9 +3,9 @@
 This module contains the immediate wrappers around the remote hosts and their
 terminals. It's possible to run commands on a host directly by using these
 classes. As an end-user of this library however, you will call the methods of
-:class:`SSHHost` and :class:`LocalHost` through
-:class:`deployer.host_container.HostsContainer`, the host proxy of a
-:class:`deployer.node.Node`.
+:class:`SSHHost <.ssh.SSHHost>` and :class:`LocalHost <.local.LocalHost>`
+through :class:`HostsContainer <deployer.host_container.HostsContainer>`, the
+host proxy of a :class:`Node <deployer.node.base.Node>`.
 """
 
 from .base import *
