@@ -22,6 +22,7 @@ from twisted.internet import fdesc
 __all__ = (
     'Host',
     'HostContext',
+    'Stat',
 )
 
 class HostContext(object):
@@ -153,13 +154,19 @@ class Stat(object):
 
 class Host(object):
     """
-    Definiton of a remote host. An instance will open an SSH connection
-    according to the settings defined in the class definition.
+    Abstract base class for SSHHost and LocalHost.
 
     :param pty: The pseudo terminal wrapper which handles the stdin/stdout.
     :type pty: :class:`deployer.pseudo_terminal.Pty`
     :param logger: The logger interface.
     :type logger: LoggerInterface
+
+    ::
+
+            class MyHost(SSHHost):
+                ...
+            my_host = MyHost()
+            my_host.run('pwd', interactive=False)
     """
     #class __metaclass__(type):
     #    @property
@@ -259,7 +266,7 @@ class Host(object):
         """
         Return the network information for this host.
 
-        :returns: A :class:`deployer.utils.IfConfig` instance.
+        :returns: An :class:`IfConfig <deployer.utils.network.IfConfig>` instance.
         """
         # We add "cd /", to be sure that at least no error get thrown because
         # we're in a non existing directory right now.
@@ -474,9 +481,9 @@ class Host(object):
             # Read/write loop
             while True:
                 # Don't wait for any input when an exit status code has been
-                # set already.
+                # set already. (But still wait for the output to finish.)
                 if chan.status_event.isSet():
-                    break;
+                    reading_from_stdin = False
 
                 channels = [self.pty.stdin, chan] if reading_from_stdin else [chan]
                 r, w, e = select(channels, [], [])
@@ -617,7 +624,7 @@ class Host(object):
 
     def listdir_stat(self, path='.'):
         """
-        Return a list of :class:`Stat` instances for each file in this directory.
+        Return a list of :class:`.Stat` instances for each file in this directory.
         """
         raise NotImplementedError
 
@@ -630,14 +637,14 @@ class Host(object):
 
         ::
 
-            with host.open('/path/to/somefile', wb') as f:
+            with host.open('/path/to/somefile', 'wb') as f:
                 f.write('some content')
 
         or:
 
         ::
 
-            host.open('/path/to/somefile', wb').write('some content')
+            host.open('/path/to/somefile', 'wb').write('some content')
         """
         # Expand path
         remote_path = os.path.normpath(os.path.join(self.getcwd(), self.expand_path(remote_path)))
