@@ -1,6 +1,6 @@
 from deployer.exceptions import ExecCommandFailed, QueryException
 from deployer.loggers import Logger, RunCallback, FileCallback, ForkCallback, Actions
-from deployer.node import ActionException
+from deployer.exceptions import ActionException
 from pygments import highlight
 from pygments.formatters import TerminalFormatter as Formatter
 from pygments.lexers import PythonTracebackLexer
